#!/bin/sh

OUTPUTDIR=$PWD
SAMPLEDIR=`dirname "$0"`
cd "$SAMPLEDIR"

if [ "$(uname -s)" = "Darwin" ]
then
        TFORMER_LIBS=/Library/Frameworks/TFORMer.framework/Libraries
        TFORMER_DATA=/Library/Frameworks/TFORMer.framework/Resources
else
        TFORMER_LIBS=/usr/local/lib
        TFORMER_DATA=/usr/local/share/TFORMer
fi
TFORMER_CLASSPATH=$TFORMER_DATA/JTFORMer70.jar

#
# Test Tomcat
#
# NOTE: we use Ubuntu directories
#
CATALINA_HOME_ROOT=/usr/share/
CATALINA_BASE_ROOT=/var/lib/
CATALINA_BIN=

# Search CATALINA_HOME
if [ "$CATALINA_HOME" != "" ]
then
	echo "Found CATALINA_HOME variable"
elif test -d $CATALINA_HOME_ROOT/tomcat5
then
	CATALINA_HOME=$CATALINA_HOME_ROOT/tomcat5
	CATALINA_BASE=$CATALINA_BASE_ROOT/tomcat5
	CATALINA_BIN=/etc/init.d/tomcat5
elif test -d $CATALINA_HOME_ROOT/tomcat6
then
	CATALINA_HOME=$CATALINA_HOME_ROOT/tomcat6
	CATALINA_BASE=$CATALINA_BASE_ROOT/tomcat6
	CATALINA_BIN=/etc/init.d/tomcat6
elif test -d $CATALINA_HOME_ROOT/tomcat7
then
	CATALINA_HOME=$CATALINA_HOME_ROOT/tomcat7
	CATALINA_BASE=$CATALINA_BASE_ROOT/tomcat7
	CATALINA_BIN=/etc/init.d/tomcat7
else
	cat << EOF
	
Error: missing Apache Tomcat

Please install Apache Tomcat (http://tomcat.apache.org/) or set the CATALINA_HOME
EOF
	exit 1
fi
echo "Found Apache Tomcat in $CATALINA_HOME"

# Check CATALINA_BASE
if test -d $CATALINA_BASE/webapps
then
	echo "Checked CATALINA_BASE variable"
elif test -d $CATALINA_HOME/webapps
then
	CATALINA_BASE=$CATALINA_HOME
else
	cat << EOF
	
Error: missing Apache Tomcat webapps directory

Please check your Apache Tomcat
EOF
	exit 1
fi

# Check CATALINA_BIN
if test -f $CATALINA_BIN
then
	echo "Checked script start/stop"
elif test -d $CATALINA_HOME/bin/catalina.sh
then
	CATALINA_BIN=$CATALINA_HOME/bin/catalina.sh
else
	cat << EOF
	
Error: missing Apache Tomcat bin directory

Please check your Apache Tomcat
EOF
	exit 1
fi

# test if the servlet library exists
# NOTE: you can find servlet-api.jar in common/lib (default directory) or in lib (Ubuntu)
SERVLETAPI=`find $CATALINA_HOME -name servlet-api.jar`
if ! test -f "$SERVLETAPI"
then
	cat << EOF
	
Errro: missing servlet library in $CATALINA_HOME

Please check your Apache Tomcat
EOF
	exit 1
fi


echo "Create the WAR structure..."
cp -Rf WebContent $OUTPUTDIR/bin
mkdir -p $OUTPUTDIR/bin/WEB-INF/classes $OUTPUTDIR/bin/WEB-INF/lib
cp $TFORMER_CLASSPATH $OUTPUTDIR/bin/WEB-INF/lib/

echo "Compiling the samples sources ..."
javac -d $OUTPUTDIR/bin/WEB-INF/classes -cp $TFORMER_CLASSPATH:$SERVLETAPI src/com/tecit/TFORMer/examples/*.java
if test $? -ne 0; then
	echo "\nERROR: Check the classpath of the script:"
	echo "\tTFORMer library: $TFORMER_CLASSPATH"
	echo "\tTOMCAT_HOME: $TOMCAT_HOME"
	exit 1
fi

echo "Create the WAR archive..."
cd $OUTPUTDIR/bin
jar cvf ../JTFORMerExample.war * > /dev/null

cat <<EOF

You can start the sample deploying the JTFORMerExample.war into your Application Server.
If you use Tomcat, follow these steps:
	
	# stop Tomcat
	sudo $CATALINA_BIN stop
 
	# copy the sample WAR file into Tomcat web applications
	sudo cp JTFORMerExample.war $CATALINA_BASE/webapps
 
	# start Tomcat with the shared library configured
	sudo LD_LIBRARY_PATH=/usr/local/lib $CATALINA_BIN start
 
	# open browser to the URL http://localhost:8080/JTFORMerExample
	firefox http://localhost:8080/JTFORMerExample


NOTE: 
Remember to add the system variable

  export LD_LIBRARY_PATH=/usr/local/lib
  
or the java option

  -Djava.library.path=/usr/local/lib
  
in order to resolve the TFORMer SDK exception

	com.tecit.TFORMer.TFormerException: No JNITFORMer library found in java.library.path
	
EOF
