package com.tecit.TFORMer.examples;
/*===========================================================================*/
/*                        Copyright (C) 2010-2012 by                         */
/*                                                                           */
/*                    -- TEC-IT Datenverarbeitung GmbH --                    */
/*   -- team for engineering and consulting in information technologies --   */
/*                                                                           */
/*                           All rights reserved.                            */
/*                                                                           */
/*              This is a part of the TEC-IT Standard Software.              */
/*                                                                           */
/*    This source code is only intended as a supplement to the References    */
/*      and related electronic documentation provided with the product.      */
/*                                                                           */
/*     See these sources for detailed information regarding this product     */
/*===========================================================================*/

import com.tecit.TFORMer.*;
import com.tecit.TFORMer.Enumerations.*;
import com.tecit.TFORMer.Printing.JobDataRecordSet;
import com.tecit.TFORMer.Printing.Job;
import com.tecit.TFORMer.Printing.JobDataRecordSet.Record;
import java.io.*;

/**
 * @author PhilipK
 * 
 */
public class Program {

	static String oName;

	/**
	 * @param args
	 */

	public static EPrinterType OutputType() {

		char c;
		int tmp;
		InputStreamReader reader = new InputStreamReader(System.in);

		EPrinterType[] ot = { EPrinterType.Default,
                          EPrinterType.PSFile,
                          EPrinterType.PDFFile,
                          EPrinterType.HTML,
                          EPrinterType.TxtFile,
                          EPrinterType.ImageBmp,
                          EPrinterType.ImageGif,
                          EPrinterType.ImageJpg,
                          EPrinterType.ImagePcx,
                          EPrinterType.ImagePng,
                          EPrinterType.ImageTga,
                          EPrinterType.ImageTifSingle,
                          EPrinterType.ImageTifMultiPage,
                          EPrinterType.ZPLFile };
		String[] fName =    { "", 			      "Output.PS", 	  "Output.PDF", 	"Output.HTML",
                          "Output.TXT",	  "Output##.BMP", "Output##.GIF", "Output##.JPG",
                          "Output##.PCX", "Output##.PNG", "Output##.TGA", "Output##.TIF",
                          "Output.TIF", 	"Output.ZPL" };
		int i = 0;
    
		try 
    {
			do {
				System.out.println("1...Print directly to default printer");
				System.out.println("2...PostScript output file");
				System.out.println("3...PDF output file");
				System.out.println("4...HTML output file");
				System.out.println("5...Text output file");
				System.out.println("6...BMP output image");
				System.out.println("7...GIF output image");
				System.out.println("8...JPG output image");
				System.out.println("9...PCX output image");
				System.out.println("A...PNG output image");
				System.out.println("B...TGA output image");
				System.out.println("C...TIF output image");
				System.out.println("D...Multipage TIF output image");
				System.out.println("E...ZPL-II output (for ZEBRA printers)\n");
				System.out.println("X...Exit");
				System.out.println("Please select:");

				tmp = reader.read();
				c = (char) tmp;
				if(c == 'X')
        {
					System.out.println("Exit...");
					System.exit(0);
				}
				i = "123456789ABCDE".indexOf(String.valueOf(c));

			} while (i < 0);
			oName = fName[i];

		} catch (Exception e) 
    {
			System.exit(1);
		}
		return ot[i];
	}

	public static void main(String[] args) {

		EPrinterType ot;
		Job job = null;
		try 
    {
			// create new job
			job = new Job();

			File file = TFORMer.getExampleFile("Demo Repository", "Demos.tfr");
			job.setRepositoryName(file.getAbsolutePath());

			job.setProjectName("TFORMer_Runtime_Examples");

			job.setFormName("BusinessCard_Multi");

			// create an in-memory data-source
			JobDataRecordSet datasource = new JobDataRecordSet();
			Record record = new JobDataRecordSet.Record();
			record.setData("Email", "sales@tec-it.com");
			record.setData("JobTitle", "Sales Assistant");
			record.setData("Name", "Mr. Harald Backoffice");
			datasource.add(record);

			record = new JobDataRecordSet.Record();
			record.setData("Email", "support@tec-it.com");
			record.setData("JobTitle", "Support Engineer");
			record.setData("Name", "Mrs. Susan Frontdesk");
			datasource.add(record);

			ot = OutputType();
			job.setPrinterType(ot);

			job.setOutputName(System.getProperty("user.dir") + File.separator + oName);

			System.out.println("Printing to " + job.getOutputName());
			// Generate Output
			job.setJobData(datasource);
			job.print();
			
			System.out.println("... \nDone");
		} 
		catch (TFormerException e) 
    {
			e.printStackTrace();
		} 
		finally 
    {
			// free the resources otherwise some memory remains allocated!
			// NOTE: the method "dispose" must be invoked also when an exception occurs (good practice is the use of finally)
			try 
      {
				if( job!=null )
					job.dispose();
			} 
			catch (TFormerException ex) 
      {
				ex.printStackTrace();
			} 
		}
	}
}
